==> apache-camel-3.8.0-src.zip: apache-camel-3.8.0/core/camel-util/src/test/java/org/apache/camel/util/ObjectHelperLoadClassTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.util;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class ObjectHelperLoadClassTest {

    @Test
    public void testLoadClass() throws Exception {
        Class<?> clazz = ObjectHelper.loadClass("int");
        Assertions.assertEquals(clazz.getName(), "int");

        clazz = ObjectHelper.loadClass("java.lang.String");
        Assertions.assertEquals(clazz.getName(), "java.lang.String");

        clazz = ObjectHelper.loadClass("java.lang.String[]");
        Assertions.assertTrue(clazz.isArray());

        clazz = ObjectHelper.loadClass("org.apache.camel.util.MyPojo");
        Assertions.assertEquals(clazz.getName(), "org.apache.camel.util.MyPojo");
        Assertions.assertFalse(clazz.isArray());

        clazz = ObjectHelper.loadClass("org.apache.camel.util.MyPojo[]");
        Assertions.assertTrue(clazz.isArray());
    }

}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/core/camel-util/src/test/java/org/apache/camel/util/ObjectHelperLoadClassTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.util;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class ObjectHelperLoadClassTest {

    @Test
    public void testLoadClass() {
        Class<?> clazz = ObjectHelper.loadClass("int");
        Assertions.assertEquals("int", clazz.getName());

        clazz = ObjectHelper.loadClass("java.lang.String");
        Assertions.assertEquals("java.lang.String", clazz.getName());

        clazz = ObjectHelper.loadClass("java.lang.String[]");
        Assertions.assertTrue(clazz.isArray());

        clazz = ObjectHelper.loadClass("org.apache.camel.util.MyPojo");
        Assertions.assertEquals("org.apache.camel.util.MyPojo", clazz.getName());
        Assertions.assertFalse(clazz.isArray());

        clazz = ObjectHelper.loadClass("org.apache.camel.util.MyPojo[]");
        Assertions.assertTrue(clazz.isArray());
    }

}
